@@ -1,6 +1,6 @@
 __author__ = "Filipe Ximenes, Andrey Ilin"
 __email__ = "andreyilin@fastmail.com"
-__version__ = "3.5.0"
+__version__ = "3.6.0"
 
 
 from .adapters import (
@@ -9,8 +9,9 @@ from .adapters import (
     FormAdapterMixin,
     JSONAdapterMixin,
     XMLAdapterMixin,
+    PydanticAdapterMixin,
 )
-from .serializers import BaseSerializer, SimpleSerializer, PydanticSerializer
+from .serializers import BaseSerializer, SimpleSerializer
 
 
 __all__ = (
@@ -19,7 +20,7 @@ __all__ = (
     "FormAdapterMixin",
     "JSONAdapterMixin",
     "XMLAdapterMixin",
+    "PydanticAdapterMixin",
     "BaseSerializer",
     "SimpleSerializer",
-    "PydanticSerializer",
 )
